# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63ommon.proto\x12\x14octopus_common_proto\"-\n\tFileChunk\x12\x0e\n\x06\x62uffer\x18\x01 \x01(\x0c\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\"\x1e\n\x0c\x46ileUploaded\x12\x0e\n\x06length\x18\x01 \x01(\x05\"#\n\x0f\x44ownloadRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FILECHUNK']._serialized_start=38
  _globals['_FILECHUNK']._serialized_end=83
  _globals['_FILEUPLOADED']._serialized_start=85
  _globals['_FILEUPLOADED']._serialized_end=115
  _globals['_DOWNLOADREQUEST']._serialized_start=117
  _globals['_DOWNLOADREQUEST']._serialized_end=152
# @@protoc_insertion_point(module_scope)
