# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent_server.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61gent_server.proto\x12\x13octopus_agent_proto\x1a\x0c\x63ommon.proto\"4\n\x0fSendTaskRequest\x12\x13\n\x0binput_files\x18\x01 \x03(\t\x12\x0c\n\x04task\x18\x02 \x01(\t\",\n\rOnAgentAction\x12\r\n\x05input\x18\x01 \x01(\t\x12\x0c\n\x04tool\x18\x02 \x01(\t\"8\n\x10OnAgentActionEnd\x12\x0e\n\x06output\x18\x01 \x01(\t\x12\x14\n\x0coutput_files\x18\x02 \x03(\t\"\x1e\n\x0c\x46inalRespond\x12\x0e\n\x06\x61nswer\x18\x01 \x01(\t\"\xdc\x04\n\x0bTaskRespond\x12\x13\n\x0btoken_usage\x18\x01 \x01(\x05\x12\x11\n\titeration\x18\x02 \x01(\x05\x12\x12\n\nmodel_name\x18\x03 \x01(\t\x12\x42\n\x0crespond_type\x18\x04 \x01(\x0e\x32,.octopus_agent_proto.TaskRespond.RespondType\x12=\n\x0fon_agent_action\x18\x05 \x01(\x0b\x32\".octopus_agent_proto.OnAgentActionH\x00\x12\x44\n\x13on_agent_action_end\x18\x06 \x01(\x0b\x32%.octopus_agent_proto.OnAgentActionEndH\x00\x12:\n\rfinal_respond\x18\x07 \x01(\x0b\x32!.octopus_agent_proto.FinalRespondH\x00\x12\x18\n\x0e\x63onsole_stdout\x18\x08 \x01(\tH\x00\x12\x18\n\x0e\x63onsole_stderr\x18\t \x01(\tH\x00\x12\x18\n\x0etyping_content\x18\n \x01(\tH\x00\"\xb5\x01\n\x0bRespondType\x12\x15\n\x11OnAgentActionType\x10\x00\x12\x17\n\x13OnAgentActionStdout\x10\x01\x12\x17\n\x13OnAgentActionStderr\x10\x02\x12\x18\n\x14OnAgentActionEndType\x10\x03\x12\x15\n\x11OnFinalAnswerType\x10\x04\x12\x15\n\x11OnAgentTextTyping\x10\x05\x12\x15\n\x11OnAgentCodeTyping\x10\x06\x42\x06\n\x04\x62ody\"1\n\x10\x41\x64\x64KernelRequest\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\".\n\x11\x41\x64\x64KernelResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"i\n\x12\x41ssembleAppRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x17\n\x0fsaved_filenames\x18\x04 \x03(\t\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\"0\n\x13\x41ssembleAppResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x1d\n\rRunAppRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"F\n\x07\x41ppInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x12\r\n\x05\x63time\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\"\x12\n\x10QueryAppsRequest\"?\n\x11QueryAppsResponse\x12*\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x1c.octopus_agent_proto.AppInfo\"\r\n\x0bPingRequest\")\n\x0cPongResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t2\xd0\x05\n\x0b\x41gentServer\x12M\n\x04ping\x12 .octopus_agent_proto.PingRequest\x1a!.octopus_agent_proto.PongResponse\"\x00\x12Q\n\x06upload\x12\x1f.octopus_common_proto.FileChunk\x1a\".octopus_common_proto.FileUploaded\"\x00(\x01\x12V\n\x08\x64ownload\x12%.octopus_common_proto.DownloadRequest\x1a\x1f.octopus_common_proto.FileChunk\"\x00\x30\x01\x12W\n\tsend_task\x12$.octopus_agent_proto.SendTaskRequest\x1a .octopus_agent_proto.TaskRespond\"\x00\x30\x01\x12]\n\nadd_kernel\x12%.octopus_agent_proto.AddKernelRequest\x1a&.octopus_agent_proto.AddKernelResponse\"\x00\x12_\n\x08\x61ssemble\x12\'.octopus_agent_proto.AssembleAppRequest\x1a(.octopus_agent_proto.AssembleAppResponse\"\x00\x12O\n\x03run\x12\".octopus_agent_proto.RunAppRequest\x1a .octopus_agent_proto.TaskRespond\"\x00\x30\x01\x12]\n\nquery_apps\x12%.octopus_agent_proto.QueryAppsRequest\x1a&.octopus_agent_proto.QueryAppsResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent_server_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SENDTASKREQUEST']._serialized_start=57
  _globals['_SENDTASKREQUEST']._serialized_end=109
  _globals['_ONAGENTACTION']._serialized_start=111
  _globals['_ONAGENTACTION']._serialized_end=155
  _globals['_ONAGENTACTIONEND']._serialized_start=157
  _globals['_ONAGENTACTIONEND']._serialized_end=213
  _globals['_FINALRESPOND']._serialized_start=215
  _globals['_FINALRESPOND']._serialized_end=245
  _globals['_TASKRESPOND']._serialized_start=248
  _globals['_TASKRESPOND']._serialized_end=852
  _globals['_TASKRESPOND_RESPONDTYPE']._serialized_start=663
  _globals['_TASKRESPOND_RESPONDTYPE']._serialized_end=844
  _globals['_ADDKERNELREQUEST']._serialized_start=854
  _globals['_ADDKERNELREQUEST']._serialized_end=903
  _globals['_ADDKERNELRESPONSE']._serialized_start=905
  _globals['_ADDKERNELRESPONSE']._serialized_end=951
  _globals['_ASSEMBLEAPPREQUEST']._serialized_start=953
  _globals['_ASSEMBLEAPPREQUEST']._serialized_end=1058
  _globals['_ASSEMBLEAPPRESPONSE']._serialized_start=1060
  _globals['_ASSEMBLEAPPRESPONSE']._serialized_end=1108
  _globals['_RUNAPPREQUEST']._serialized_start=1110
  _globals['_RUNAPPREQUEST']._serialized_end=1139
  _globals['_APPINFO']._serialized_start=1141
  _globals['_APPINFO']._serialized_end=1211
  _globals['_QUERYAPPSREQUEST']._serialized_start=1213
  _globals['_QUERYAPPSREQUEST']._serialized_end=1231
  _globals['_QUERYAPPSRESPONSE']._serialized_start=1233
  _globals['_QUERYAPPSRESPONSE']._serialized_end=1296
  _globals['_PINGREQUEST']._serialized_start=1298
  _globals['_PINGREQUEST']._serialized_end=1311
  _globals['_PONGRESPONSE']._serialized_start=1313
  _globals['_PONGRESPONSE']._serialized_end=1354
  _globals['_AGENTSERVER']._serialized_start=1357
  _globals['_AGENTSERVER']._serialized_end=2077
# @@protoc_insertion_point(module_scope)
